:mod:`exspy.material`
---------------------

.. currentmodule:: exspy.material

.. autosummary::

    atomic_to_weight
    weight_to_atomic
    density_of_mixture
    mass_absorption_coefficient
    mass_absorption_mixture

.. automodule:: exspy.material
   :members: